"""
Type annotations for botocore.docs.service module.

Copyright 2025 Vlad Emelianov
"""

from botocore.docs.bcdoc.restdoc import DocumentStructure
from botocore.session import Session

class ServiceDocumenter:
    def __init__(self, service_name: str, session: Session, root_docs_path: str) -> None: ...
    def document_service(self) -> bytes: ...
    def title(self, section: DocumentStructure) -> None: ...
    def table_of_contents(self, section: DocumentStructure) -> None: ...
    def client_api(self, section: DocumentStructure) -> None: ...
    def client_exceptions(self, section: DocumentStructure) -> None: ...
    def paginator_api(self, section: DocumentStructure) -> None: ...
    def waiter_api(self, section: DocumentStructure) -> None: ...
    def get_examples(self, service_name: str, api_version: str | None = ...) -> list[str]: ...
    def client_context_params(self, section: DocumentStructure) -> None: ...
